## Product details

Add function and style to your home with the Better Homes & Gardens 8-Cube Storage Organizer. Available in multiple finishes, this cube organizer features eight 13" x 15" x 13" compartments, the perfect size to display books, collectibles, photos, artwork, storage bins and baskets. An open back design makes it easy to manage cords and cables. This sturdy bookcase can stand vertically or horizontally to best make use of space. The top panel supports up to 100 lbs when vertical, and 150 lbs when horizontal. Combine it with other Better Homes & Gardens Cube Organizers and Cube Storage Bins (sold separately) to create a complete storage and display system. Easy to assemble with included wall attachment safety system, the Better Homes & Gardens 8-Cube Storage Organizer is perfect for your office, living room, den, playroom and more.

Better Homes & Gardens 8-Cube Storage Organizer, White Texture
Sleek, open-back design for easy cord management
Features eight 13" x 15" x 13" compartments
Compatible with Better Homes & Gardens Cube Storage Bins (sold separately)
Versatile design allows for vertical or horizontal placement
Top panel can support up to 100 lbs when vertical, 150 lbs when horizontal
Each cube supports up to 30 lbs
Dimensions: 30.16" x 15.35" x 56.77"
Weight: 55.57 lbs
Can be combined with other Better Homes & Gardens Storage Organizers and Shelves (sold separately)
Materials: MDF, particle board, paperboard and iron
Attaches to wall with included safety strap
Easy to assemble with included instructions and video assembly guide
Tools required: hammer, Phillips head screwdriver, flat head screwdriver
Finishes available: Textured White (BH61100005913WH), Tobacco Oak (BH61100005913TO), Natural (BH61100005913NA), Rustic Gray (BHD036118664025), Solid Black (BHD036118664023) and Gray (BHD036118664024)
Site to Store Pickup Note: This item is packaged in one large box that may not fit in a standard-sized vehicle. Please make sure you have a large car or truck for store pickup.
Package dimensions: 58.27" x 8.78" x 18.5"
Package weight: 65.08 lbs
Assembly Video: Better Homes & Gardens 8-Cube Organizer
For customer support or assembly assistance, visit huisenfurniture.zendesk.com or call 1-800-729-1569.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## cSpecifications

Bookcase type
Cube Bookcases
Finish
Textured Wood Grain
Compartments
8
Assembled product height
56.77 in
More details
## Warranty

Warranty information
1 Year Limited Manufacturer Warranty
Warranty url
https://huisenfurniture.zendesk.com/hc/en-us/articles/17222901561371-Better-Homes-Gardens-8-Cube-Organizer-Malaysia-
Warnings

## Warning
WARNING: This product can expose you to chemicals including formaldehyde (gas), which is known to the State of California to cause cancer or birth defects or other reproductive harm. For more information go to www.P65Warnings.ca.gov/furniture.
State Chemical Disclosure
None
